==> tencentcloud-sdk-java-3.1.79-sources.jar: com/tencentcloudapi/dayu/v20180709/models/Paging.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.dayu.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Paging extends AbstractModel{

    /**
    * 起始位置
    */
    @SerializedName("Offset")
    @Expose
    private Long Offset;

    /**
    * 数量
    */
    @SerializedName("Limit")
    @Expose
    private Long Limit;

    /**
     * Get 起始位置 
     * @return Offset 起始位置
     */
    public Long getOffset() {
        return this.Offset;
    }

    /**
     * Set 起始位置
     * @param Offset 起始位置
     */
    public void setOffset(Long Offset) {
        this.Offset = Offset;
    }

    /**
     * Get 数量 
     * @return Limit 数量
     */
    public Long getLimit() {
        return this.Limit;
    }

    /**
     * Set 数量
     * @param Limit 数量
     */
    public void setLimit(Long Limit) {
        this.Limit = Limit;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Offset", this.Offset);
        this.setParamSimple(map, prefix + "Limit", this.Limit);

    }
}

==> tencentcloud-sdk-java-3.1.425-sources.jar: com/tencentcloudapi/dayu/v20180709/models/Paging.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.dayu.v20180709.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class Paging extends AbstractModel{

    /**
    * 起始位置
    */
    @SerializedName("Offset")
    @Expose
    private Long Offset;

    /**
    * 数量
    */
    @SerializedName("Limit")
    @Expose
    private Long Limit;

    /**
     * Get 起始位置 
     * @return Offset 起始位置
     */
    public Long getOffset() {
        return this.Offset;
    }

    /**
     * Set 起始位置
     * @param Offset 起始位置
     */
    public void setOffset(Long Offset) {
        this.Offset = Offset;
    }

    /**
     * Get 数量 
     * @return Limit 数量
     */
    public Long getLimit() {
        return this.Limit;
    }

    /**
     * Set 数量
     * @param Limit 数量
     */
    public void setLimit(Long Limit) {
        this.Limit = Limit;
    }

    public Paging() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public Paging(Paging source) {
        if (source.Offset != null) {
            this.Offset = new Long(source.Offset);
        }
        if (source.Limit != null) {
            this.Limit = new Long(source.Limit);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "Offset", this.Offset);
        this.setParamSimple(map, prefix + "Limit", this.Limit);

    }
}
